@@ -1,14 +1,10 @@
-import getpass
 import os
-import sys
 
-import github
 import jinja2
 import plumbum
 
 from devassistant import exceptions
 from devassistant import settings
-from devassistant.logger import logger
 from devassistant.command_helpers import ClHelper, PathHelper, RPMHelper, YUMHelper
 
 class AssistantBase(object):
@@ -67,7 +63,6 @@ class AssistantBase(object):
     def is_run_as_leaf(self, **kwargs):
         """Returns True if this assistant was run as last in path, False otherwise."""
         # find the last subassistant_N
-        leaf_class = None
         i = 0
         while i < len(kwargs): # len(kwargs) is maximum of subassistant_N keys
             if settings.SUBASSISTANT_N_STRING.format(i) in kwargs:
@@ -128,66 +123,3 @@ class AssistantBase(object):
             ClHelper.run_command('git init')
             ClHelper.run_command('git add .')
             ClHelper.run_command('git commit -m "Initial commit."')
-
-    def _github_username(self, **kwargs):
-        return kwargs['github'] or getpass.getuser()
-
-    def _github_reponame(self, **kwargs):
-        """Extracts reponame from name, which is possibly a path."""
-        return os.path.basename(kwargs['name'])
-
-    def _github_create_repo(self, **kwargs):
-        """Create repo on GitHub.
-
-        If repository already exists then RunException will be raised.
-
-        Raises:
-            devassistant.exceptions.RunException on error
-        """
-        username = self._github_username(**kwargs)
-        reponame = self._github_reponame(**kwargs)
-        password = getpass.getpass(prompt='GitHub password:', stream=None)
-
-        gh = github.Github(username, password)
-        user = gh.get_user()
-        try:
-            if reponame in map(lambda x: x.name, user.get_repos()):
-                logger.warning("Repository already exists on GiHub.")
-            else:
-                user.create_repo(reponame)
-        except github.GithubException as e:
-            raise exceptions.RunException('GitHub error: {0}'.format(e))
-
-    def _github_push(self, **kwargs):
-        """Add a remote and push to GitHub.
-
-        Raises:
-            devassistant.exceptions.RunException on error
-        """
-        username = self._github_username(**kwargs)
-        reponame = self._github_reponame(**kwargs)
-        has_remote = False
-
-        try:
-            result = ClHelper.run_command("git remote show origin")
-            has_remote = True
-        except plumbum.ProcessExecutionError as e:
-            pass
-
-        if not has_remote:
-            try:
-                ClHelper.run_command("git remote add origin https://github.com/{0}/{1}.git".format(username, reponame), True, True)
-            except plumbum.ProcessExecutionError as e:
-                pass # TODO: what exactly happens here?
-
-        ClHelper.run_command("git push origin master", True, True)
-
-    def _github_create_and_push(self, **kwargs):
-        with plumbum.local.cwd(os.path.abspath(os.path.expanduser(kwargs['name']))):
-            ClHelper.run_command('cd {0}'.format(os.path.abspath(os.path.expanduser(kwargs['name']))))
-            logger.info('Registering your project on GitHub as {0}/{1}...'.format(self._github_username(**kwargs),
-                                                                                  self._github_reponame(**kwargs)))
-            self._github_create_repo(**kwargs)
-            logger.info('Pushing your project to the new GitHub repository...')
-            self._github_push(**kwargs)
-            logger.info('GitHub repository was created and source code pushed.')
