@@ -28,7 +28,7 @@ class TestYamlAssistant(object):
 
     # TODO: refactor to also test _dependencies_section alone
     def test_dependencies(self):
-        self.ya._dependencies = [{'default': [{'rpm': ['foo', '@bar', 'baz']}]}]
+        self.ya._dependencies = [{'rpm': ['foo', '@bar', 'baz']}]
         flexmock(RPMHelper).should_receive('is_rpm_installed').and_return(False, True).one_by_one()
         flexmock(YUMHelper).should_receive('is_group_installed').and_return(False)
         flexmock(YUMHelper).should_receive('install').with_args('foo', '@bar').and_return(True)
@@ -37,7 +37,8 @@ class TestYamlAssistant(object):
         self.ya.dependencies()
 
     def test_dependencies_uses_non_default_section_on_param(self):
-        self.ya._dependencies = [{'default': [{'rpm': ['foo']}]}, {'_a': [{'rpm': ['bar']}]}]
+        self.ya._dependencies = [{'rpm': ['foo']}]
+        self.ya._dependencies_a = [{'rpm': ['bar']}]
         flexmock(RPMHelper).should_receive('is_rpm_installed').and_return(False, False).one_by_one()
         flexmock(YUMHelper).should_receive('install').with_args('foo').and_return(True)
         flexmock(YUMHelper).should_receive('install').with_args('bar').and_return(True)
@@ -45,7 +46,8 @@ class TestYamlAssistant(object):
         self.ya.dependencies(a=True)
 
     def test_dependencies_does_not_use_non_default_section_when_param_not_present(self):
-        self.ya._dependencies = [{'default': [{'rpm': ['foo']}]}, {'_a': [{'rpm': ['bar']}]}]
+        self.ya._dependencies = [{'rpm': ['foo']}]
+        self.ya._dependencies_a = [{'rpm': ['bar']}]
         flexmock(RPMHelper).should_receive('is_rpm_installed').and_return(False, False).one_by_one()
         flexmock(YUMHelper).should_receive('install').with_args('foo').and_return(True)
         flexmock(RPMHelper).should_receive('was_rpm_installed').and_return(True)
